@@ -377,9 +377,15 @@ class Backend implements Serializable
             }
         }
         $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE); 
-        if ($httpCode != 200) {
-            $App->log('[Backend/query] HTTP ERROR '.$httpCode.', query: "'.$query.'"');
-            throw new Exception('ERR_REST_'.$httpCode);
+        switch ($httpCode) {
+            case 200:
+                break;
+            case 401:
+                $App->log('[Backend/query] HTTP STATUS '.$httpCode.', REST backed password incorrect.');
+                throw new Exception('ERR_REST_'.$httpCode);
+            default:
+                $App->log('[Backend/query] HTTP ERROR '.$httpCode.', query: "'.$query.'"');
+                throw new Exception('ERR_REST_'.$httpCode);
         }
 
         // split header / body
