@@ -146,17 +146,14 @@ class UserDA extends Persistence
             return $this->loadSExternal($script,$loadpass);
         }
         catch (Exception $e) {
-            $esc = $e->getMessage();
-            if ($esc == 'ERR_AUTH') {
-                throw new Exception('ERR_AUTH');
-            }
-            if ($esc != 'ERR_EXECUTE') {
-                // external auth via STDIN failed
-                $App->log('External auth with STDIN protocol failed.');
-            }
-            else { 
-                throw new Exception('ERR_EXECUTE');
-            }
+            $exc = $e->getMessage();
+            $App->log("Authentication error: $exc",2,'User/loadExternal');
+              if ($App->getConfig('DISABLE_DEPRECATED') === true) {
+                  if ($exc == 'ERR_NOUSER') {
+                      throw new Exception('ERR_AUTH');    // disguise unknown username
+                  }
+                  throw new Exception($exc);
+              }
         }
 
         if ($loadpass === false) {
@@ -167,19 +164,9 @@ class UserDA extends Persistence
             $this->password = $loadpass;
         }
 
-        // call script an read userdata from stdout
-        //
-        // Returnvalues:
-        //  ERROR ERR_AUTH | ERR_INTERN | (symbol in benno-errors.txt)
-        //  ROLE USER | REVISOR | ADMIN
-        //  DISPLAYNAME Martin Werthmöller
-        //  ARCHIVE LWsystems
-        //  MAIL mw@lw-systems.de
-        //  MAIL m.werthmoeller@lw-systems.de
-        //  MAIL info@lw-systems.de
         $cmd = escapeshellcmd($script);
         $username = escapeshellcmd($this->id);
-        $App->log('(DEPRECATED) Call "'.$script.'" to authenticate.',0);
+        $App->log('(DEPRECATED) Call "'.$script.'" to authenticate.',0,'User/loadExternal');
         $retvalue = shell_exec("$cmd \"$username\" \"$password\"");
         return $this->_check_external_return($retvalue);
     }
@@ -231,7 +218,7 @@ class UserDA extends Persistence
             $errvalue = stream_get_contents($pipes[2]);
             fclose($pipes[2]);
             if ($errvalue) {
-                error_log('Authentication script error: '.$errvalue);
+                $App->log('Authentication script error: '.$errvalue,3,'User/loadSExternal');
             }
 
             $return_value = proc_close($process);
@@ -499,7 +486,7 @@ class UserDA extends Persistence
 
         // deprecated
         if (empty($this->archive)) {
-            $App->log('WARN: container table has no entries for '.$this->id);
+            $App->log('WARN: container table has no entries for '.$this->id,2);
             $sql = "SELECT archive FROM user WHERE id = ?";
             $sth = $DB->db->prepare($sql);
             $sth->bindValue(1,$this->id);
